baseObjects.DocumentStore

|  | ## Cheshire3 Object Model: Class DocumentStore

Module baseObjects :: Class DocumentStore

## Class DocumentStore
source code

Object Tree:

               object --+
                        |
    configParser.C3Object --+
                            |
                  ObjectStore --+
                                |
                               DocumentStore

Known Subclasses:
  documentStore.SimpleDocumentStore

An interface to a persistent storage mechanism for Documents and their associated metadata.
Instance Methods

create_document(self, session, doc=None)
delete_document(self, session, id)
fetch_document(self, session, id)
fetch_documentList(self, session, req)
store_document(self, session, doc)
Inherited from `ObjectStore`: `create_object`, `delete_object`, `fetch_object`, `store_object` Inherited from `configParser.C3Object`: `__init__`, `auth_function`, `get_config`, `get_default`, `get_object`, `get_path`, `get_setting`, `log_function`, `unauth_function`, `unlog_function` Inherited from `configParser.C3Object` (private): `_getDomFromFile`, `_handleConfigNode`, `_parseIncludes`, `_recurseSubConfigs`, `_verifyDefault`, `_verifyOption`, `_verifySetting` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables

Inherited from `configParser.C3Object`: `configStore`, `defaults`, `functionLogger`, `id`, `name`, `objectType`, `objects`, `parent`, `paths`, `permissionHandlers`, `settings`, `subConfigs`, `unresolvedObjects` Inherited from `configParser.C3Object` (private): `_includeConfigStores`, `_objectRefs` Inherited from `object`: `__class__`

Method Details

### create_document(self, session, doc=None) | source code

### delete_document(self, session, id) | source code

### fetch_document(self, session, id) | source code

### fetch_documentList(self, session, req) | source code

### store_document(self, session, doc) | source code